@@ -26,22 +26,6 @@
 using namespace Akonadi;
 using namespace Akonadi::Protocol;
 
-void ProtocolTest::testProtocolVersion()
-{
-    // So, this test started failing because you bumped protocol version in
-    // protocol.cpp. That means that you most probably changed something
-    // in the protocol. Before you just bump the number here to make the test
-    // pass, please please pretty please make sure to extend the respective
-    // test somewhere below to cover the change you've made. Protocol is the
-    // most critical part of Akonadi and we can't afford not having it tested
-    // properly.
-    //
-    // If it wasn't you who broke it, please go find that person who was too
-    // lazy to extend the test case and beat them with a stick. -- Dan
-
-    QCOMPARE(Akonadi::Protocol::version(), 59);
-}
-
 void ProtocolTest::testFactory_data()
 {
     QTest::addColumn<Command::Type>("type");
@@ -249,7 +233,6 @@ void ProtocolTest::testFetchScope()
 
     in.setRequestedParts(requestedParts);
     in.setChangedSince(QDateTime(QDate(2015, 8, 10), QTime(23, 52, 20), Qt::UTC));
-    in.setTagFetchScope({ "TAGID" });
     in.setAncestorDepth(ItemFetchScope::AllAncestors);
     in.setFetch(ItemFetchScope::CacheOnly);
     in.setFetch(ItemFetchScope::CheckCachedPayloadPartsOnly);
@@ -270,7 +253,6 @@ void ProtocolTest::testFetchScope()
     QCOMPARE(out.requestedParts(), expectedParts);
     QCOMPARE(out.requestedPayloads(), expectedPayloads);
     QCOMPARE(out.changedSince(), QDateTime(QDate(2015, 8, 10), QTime(23, 52, 20), Qt::UTC));
-    QCOMPARE(out.tagFetchScope(), QSet<QByteArray>{ "TAGID" });
     QCOMPARE(out.ancestorDepth(), ItemFetchScope::AllAncestors);
     QCOMPARE(out.fetch(ItemFetchScope::None), false);
     QCOMPARE(out.cacheOnly(), true);
