@@ -23,8 +23,8 @@
 
 using namespace Akonadi::Server;
 
-FakeSearchManager::FakeSearchManager(QObject *parent)
-    : SearchManager(QStringList(), parent)
+FakeSearchManager::FakeSearchManager(SearchTaskManager &agentSearchManager)
+    : SearchManager(QStringList(), agentSearchManager)
 {
 }
 
