@@ -26,6 +26,7 @@
 #include "storage/itemretrievaljob.h"
 #include "storage/itemretrievalmanager.h"
 #include "storage/itemretrievalrequest.h"
+#include "commandcontext.h"
 
 #include "fakeakonadiserver.h"
 #include "dbinitializer.h"
@@ -150,14 +151,15 @@ using RequestedParts = QVector<QByteArray /* FQ name */>;
 class ClientThread : public QThread
 {
 public:
-    ClientThread(Entity::Id itemId, const RequestedParts &requestedParts)
-        : m_itemId(itemId), m_requestedParts(requestedParts)
+    ClientThread(Entity::Id itemId, const RequestedParts &requestedParts, ItemRetrievalManager &manager)
+        : m_itemId(itemId), m_requestedParts(requestedParts), m_manager(manager)
     {}
 
     void run() override
     {
         // ItemRetriever should...
-        ItemRetriever retriever;
+        CommandContext context;
+        ItemRetriever retriever(m_manager, nullptr, context);
         retriever.setItem(m_itemId);
         retriever.setRetrieveParts(m_requestedParts);
         QSignalSpy spy(&retriever, &ItemRetriever::itemsRetrieved);
@@ -186,6 +188,7 @@ public:
 private:
     const Entity::Id m_itemId;
     const RequestedParts m_requestedParts;
+    ItemRetrievalManager &m_manager;
 
     mutable QMutex m_mutex; // protects results below
     Results m_results;
@@ -199,24 +202,21 @@ class ItemRetrieverTest : public QObject
     using ExistingParts = QVector<QPair<QByteArray /* name */, QByteArray /* data */>>;
     using AvailableParts = QVector<QPair<QByteArray /* name */, QByteArray /* data */>>;
 
+    FakeAkonadiServer mAkonadi;
 public:
     ItemRetrieverTest()
         : QObject()
     {
-        FakeAkonadiServer::instance()->setPopulateDb(false);
-        FakeAkonadiServer::instance()->disableItemRetrievalManager();
-        FakeAkonadiServer::instance()->init();
-    }
-
-    ~ItemRetrieverTest()
-    {
-        FakeAkonadiServer::instance()->quit();
+        mAkonadi.setPopulateDb(false);
+        mAkonadi.disableItemRetrievalManager();
+        mAkonadi.init();
     }
 
 private Q_SLOTS:
     void testFullPayload()
     {
-        ItemRetriever r1(nullptr);
+        CommandContext context;
+        ItemRetriever r1(mAkonadi.itemRetrievalManager(), nullptr, context);
         r1.setRetrieveFullPayload(true);
         QCOMPARE(r1.retrieveParts().size(), 1);
         QCOMPARE(r1.retrieveParts().at(0), { "PLD:RFC822" });
@@ -314,7 +314,7 @@ private Q_SLOTS:
             }
 
             if (step == 0) {
-                ClientThread thread(item.id(), requestedParts);
+                ClientThread thread(item.id(), requestedParts, mgr);
                 thread.run();
 
                 const ClientThread::Results results = thread.results();
@@ -333,7 +333,7 @@ private Q_SLOTS:
             } else {
                 QVector<ClientThread *> threads;
                 for (int i = 0; i < 20; ++i) {
-                    threads.append(new ClientThread(item.id(), requestedParts));
+                    threads.append(new ClientThread(item.id(), requestedParts, mgr));
                 }
                 for (int i = 0; i < threads.size(); ++i) {
                     threads.at(i)->start();
