@@ -22,7 +22,7 @@
 
 #include "agenttype_p.h"
 #include "agentinstance_p.h"
-#include "KDBusConnectionPool"
+#include <QDBusConnection>
 #include "servermanager.h"
 #include "collection.h"
 
@@ -309,18 +309,6 @@ AgentInstance AgentManagerPrivate::fillAgentInstanceLight(const QString &identif
     return instance;
 }
 
-void AgentManagerPrivate::serviceOwnerChanged(const QString &, const QString &oldOwner, const QString &)
-{
-    if (oldOwner.isEmpty()) {
-        if (mTypes.isEmpty()) { // just to be safe
-            readAgentTypes();
-        }
-        if (mInstances.isEmpty()) {
-            readAgentInstances();
-        }
-    }
-}
-
 void AgentManagerPrivate::createDBusInterface()
 {
     mTypes.clear();
@@ -329,7 +317,7 @@ void AgentManagerPrivate::createDBusInterface()
 
     mManager = new org::freedesktop::Akonadi::AgentManager(ServerManager::serviceName(ServerManager::Control),
             QStringLiteral("/AgentManager"),
-            KDBusConnectionPool::threadConnection(), mParent);
+            QDBusConnection::sessionBus(), mParent);
 
     QObject::connect(mManager, SIGNAL(agentTypeAdded(QString)),
                      mParent, SLOT(agentTypeAdded(QString)));
@@ -370,11 +358,18 @@ AgentManager::AgentManager()
 
     d->createDBusInterface();
 
-    QDBusServiceWatcher *watcher = new QDBusServiceWatcher(ServerManager::serviceName(ServerManager::Control),
-            KDBusConnectionPool::threadConnection(),
-            QDBusServiceWatcher::WatchForOwnerChange, this);
-    connect(watcher, &QDBusServiceWatcher::serviceOwnerChanged,
-            this, [this](const QString &arg1, const QString &arg2 , const QString &arg3) { d->serviceOwnerChanged(arg1, arg2, arg3); });
+    d->mServiceWatcher = std::make_unique<QDBusServiceWatcher>(
+            ServerManager::serviceName(ServerManager::Control), QDBusConnection::sessionBus(),
+            QDBusServiceWatcher::WatchForRegistration);
+    connect(d->mServiceWatcher.get(), &QDBusServiceWatcher::serviceRegistered,
+            this, [this]() {
+                if (d->mTypes.isEmpty()) { // just to be safe
+                    d->readAgentTypes();
+                }
+                if (d->mInstances.isEmpty()) {
+                    d->readAgentInstances();
+                }
+            });
 }
 
 // @endcond
@@ -395,7 +390,8 @@ AgentManager *AgentManager::self()
 
 AgentType::List AgentManager::types() const
 {
-    // Maybe the Control process is up and ready but we haven't been to the event loop yet so serviceOwnerChanged wasn't called yet.
+    // Maybe the Control process is up and ready but we haven't been to the event loop yet so
+    // QDBusServiceWatcher hasn't notified us yet.
     // In that case make sure to do it here, to avoid going into Broken state.
     if (d->mTypes.isEmpty()) {
         d->readAgentTypes();
