@@ -17,8 +17,8 @@
     02110-1301, USA.
 */
 
-#ifndef AKONADICORE_COMMANDBUFFER_H_
-#define AKONADICORE_COMMANDBUFFER_H_
+#ifndef AKONADICORE_COMMANDBUFFER_P_H_
+#define AKONADICORE_COMMANDBUFFER_P_H_
 
 class QObject;
 
