@@ -19,10 +19,8 @@
 */
 
 #include "entityrightsfiltermodel.h"
-
 #include "entitytreemodel.h"
 
-
 using namespace Akonadi;
 
 namespace Akonadi
@@ -70,9 +68,10 @@ public:
 }
 
 EntityRightsFilterModel::EntityRightsFilterModel(QObject *parent)
-    : KRecursiveFilterProxyModel(parent)
+    : QSortFilterProxyModel(parent)
     , d_ptr(new EntityRightsFilterModelPrivate(this))
 {
+    setRecursiveFilteringEnabled(true);
 }
 
 EntityRightsFilterModel::~EntityRightsFilterModel()
@@ -80,6 +79,16 @@ EntityRightsFilterModel::~EntityRightsFilterModel()
     delete d_ptr;
 }
 
+
+bool EntityRightsFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
+{
+    Q_D(const EntityRightsFilterModel);
+
+    const QModelIndex modelIndex = sourceModel()->index(sourceRow, 0, sourceParent);
+
+    return d->rightsMatches(modelIndex);
+}
+
 void EntityRightsFilterModel::setAccessRights(Collection::Rights rights)
 {
     Q_D(EntityRightsFilterModel);
@@ -93,23 +102,14 @@ Collection::Rights EntityRightsFilterModel::accessRights() const
     return d->mAccessRights;
 }
 
-bool EntityRightsFilterModel::acceptRow(int sourceRow, const QModelIndex &sourceParent) const
-{
-    Q_D(const EntityRightsFilterModel);
-
-    const QModelIndex modelIndex = sourceModel()->index(sourceRow, 0, sourceParent);
-
-    return d->rightsMatches(modelIndex);
-}
-
 Qt::ItemFlags EntityRightsFilterModel::flags(const QModelIndex &index) const
 {
     Q_D(const EntityRightsFilterModel);
 
     if (d->rightsMatches(index)) {
-        return KRecursiveFilterProxyModel::flags(index);
+        return QSortFilterProxyModel::flags(index);
     } else {
-        return KRecursiveFilterProxyModel::flags(index) & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+        return QSortFilterProxyModel::flags(index) & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
     }
 }
 
