@@ -49,18 +49,19 @@ using namespace Akonadi::Server;
 #define IDLE_TIMER_TIMEOUT 180000 // 3 min
 
 static QString connectionIdentifier(Connection *c) {
-    QString id;
-    id.sprintf("%p", static_cast<void *>(c));
+    const QString id = QString::asprintf("%p", static_cast<void *>(c));
     return id;
 }
 
-Connection::Connection(QObject *parent)
-    : AkThread(connectionIdentifier(this), QThread::InheritPriority, parent)
+Connection::Connection(AkonadiServer &akonadi)
+    : AkThread(connectionIdentifier(this), QThread::InheritPriority)
+    , m_akonadi(akonadi)
 {
 }
 
-Connection::Connection(quintptr socketDescriptor, QObject *parent)
-    : AkThread(connectionIdentifier(this), QThread::InheritPriority, parent)
+Connection::Connection(quintptr socketDescriptor, AkonadiServer &akonadi)
+    : AkThread(connectionIdentifier(this), QThread::InheritPriority)
+    , m_akonadi(akonadi)
 {
     m_socketDescriptor = socketDescriptor;
     m_identifier = connectionIdentifier(this); // same as objectName()
@@ -73,30 +74,27 @@ void Connection::init()
 {
     AkThread::init();
 
-    QLocalSocket *socket = new QLocalSocket();
-
+    auto socket = std::make_unique<QLocalSocket>();
     if (!socket->setSocketDescriptor(m_socketDescriptor)) {
         qCWarning(AKONADISERVER_LOG) << "Connection(" << m_identifier
                                      << ")::run: failed to set socket descriptor: "
-                                     << socket->error() << "(" << socket->errorString() << ")";
-        delete socket;
+                                     << socket->error()
+                                     << "(" << socket->errorString() << ")";
         return;
     }
 
-    m_socket = socket;
-    connect(socket, &QLocalSocket::disconnected,
-            this, &Connection::slotSocketDisconnected);
+    m_socket = std::move(socket);
+    connect(m_socket.get(), &QLocalSocket::disconnected, this, &Connection::slotSocketDisconnected);
 
-    m_idleTimer = new QTimer(this);
-    connect(m_idleTimer, &QTimer::timeout,
-            this, &Connection::slotConnectionIdle);
+    m_idleTimer = std::make_unique<QTimer>();
+    connect(m_idleTimer.get(), &QTimer::timeout, this, &Connection::slotConnectionIdle);
 
     storageBackend()->notificationCollector()->setConnection(this);
 
-    if (socket->state() == QLocalSocket::ConnectedState) {
+    if (m_socket->state() == QLocalSocket::ConnectedState) {
         QTimer::singleShot(0, this, &Connection::handleIncomingData);
     } else {
-        connect(socket, &QLocalSocket::connected, this, &Connection::handleIncomingData,
+        connect(m_socket.get(), &QLocalSocket::connected, this, &Connection::handleIncomingData,
                 Qt::QueuedConnection);
     }
 
@@ -116,15 +114,10 @@ void Connection::quit()
         return;
     }
 
-    Tracer::self()->endConnection(m_identifier, QString());
+    m_akonadi.tracer().endConnection(m_identifier, QString());
 
-    delete m_socket;
-    m_socket = nullptr;
-
-    if (m_idleTimer) {
-        m_idleTimer->stop();
-    }
-    delete m_idleTimer;
+    m_socket.reset();
+    m_idleTimer.reset();
 
     AkThread::quit();
 }
@@ -210,8 +203,8 @@ void Connection::handleIncomingData()
         // and similar while waiting for some data to arrive
         if (m_socket->bytesAvailable() < int(sizeof(qint64))) {
             QEventLoop loop;
-            connect(m_socket, &QLocalSocket::readyRead, &loop, &QEventLoop::quit);
-            connect(m_socket, &QLocalSocket::stateChanged, &loop, &QEventLoop::quit);
+            connect(m_socket.get(), &QLocalSocket::readyRead, &loop, &QEventLoop::quit);
+            connect(m_socket.get(), &QLocalSocket::stateChanged, &loop, &QEventLoop::quit);
             connect(this, &Connection::connectionClosing, &loop, &QEventLoop::quit);
             loop.exec();
         }
@@ -230,14 +223,14 @@ void Connection::handleIncomingData()
 
         QString currentCommand;
         while (m_socket->bytesAvailable() >= int(sizeof(qint64))) {
-            Protocol::DataStream stream(m_socket);
+            Protocol::DataStream stream(m_socket.get());
             qint64 tag = -1;
             stream >> tag;
             // TODO: Check tag is incremental sequence
 
             Protocol::CommandPtr cmd;
             try {
-                cmd = Protocol::deserialize(m_socket);
+                cmd = Protocol::deserialize(m_socket.get());
             } catch (const Akonadi::ProtocolException &e) {
                 qCWarning(AKONADISERVER_LOG) << "ProtocolException while deserializing incoming data on connection"
                                              << m_identifier << ":" <<  e.what();
@@ -257,10 +250,10 @@ void Connection::handleIncomingData()
             }
 
             // Tag context and collection context is not persistent.
-            context()->setTag(-1);
-            context()->setCollection(Collection());
-            if (Tracer::self()->currentTracer() != QLatin1String("null")) {
-                Tracer::self()->connectionInput(m_identifier, tag, cmd);
+            m_context.setTag(nullopt);
+            m_context.setCollection({});
+            if (m_akonadi.tracer().currentTracer() != QLatin1String("null")) {
+                m_akonadi.tracer().connectionInput(m_identifier, tag, cmd);
             }
 
             m_currentHandler = findHandlerForCommand(cmd->type());
@@ -357,26 +350,29 @@ void Connection::handleIncomingData()
     }
 }
 
-CommandContext *Connection::context() const
+const CommandContext &Connection::context() const
 {
-    return const_cast<CommandContext *>(&m_context);
+    return m_context;
+}
+
+void Connection::setContext(const CommandContext &context)
+{
+    m_context = context;
 }
 
 std::unique_ptr<Handler> Connection::findHandlerForCommand(Protocol::Command::Type command)
 {
-    auto handler = Handler::findHandlerForCommandAlwaysAllowed(command);
+    auto handler = Handler::findHandlerForCommandAlwaysAllowed(command, m_akonadi);
     if (handler) {
         return handler;
     }
 
     switch (m_connectionState) {
     case NonAuthenticated:
-        handler =  Handler::findHandlerForCommandNonAuthenticated(command);
+        handler =  Handler::findHandlerForCommandNonAuthenticated(command, m_akonadi);
         break;
     case Authenticated:
-        handler =  Handler::findHandlerForCommandAuthenticated(command);
-        break;
-    case Selected:
+        handler =  Handler::findHandlerForCommandAuthenticated(command, m_akonadi);
         break;
     case LoggingOut:
         break;
@@ -402,8 +398,6 @@ void Connection::setState(ConnectionState state)
         break;
     case Authenticated:
         break;
-    case Selected:
-        break;
     case LoggingOut:
         m_socket->disconnectFromServer();
         break;
@@ -412,8 +406,8 @@ void Connection::setState(ConnectionState state)
 
 void Connection::setSessionId(const QByteArray &id)
 {
-    m_identifier.sprintf("%s (%p)", id.data(), static_cast<void *>(this));
-    Tracer::self()->beginConnection(m_identifier, QString());
+    m_identifier = QString::asprintf("%s (%p)", id.data(), static_cast<void *>(this));
+    m_akonadi.tracer().beginConnection(m_identifier, QString());
     //m_streamParser->setTracerIdentifier(m_identifier);
 
     m_sessionId = id;
@@ -430,7 +424,7 @@ QByteArray Connection::sessionId() const
 
 bool Connection::isOwnerResource(const PimItem &item) const
 {
-    if (context()->resource().isValid() && item.collection().resourceId() == context()->resource().id()) {
+    if (context().resource().isValid() && item.collection().resourceId() == context().resource().id()) {
         return true;
     }
     // fallback for older resources
@@ -442,7 +436,7 @@ bool Connection::isOwnerResource(const PimItem &item) const
 
 bool Connection::isOwnerResource(const Collection &collection) const
 {
-    if (context()->resource().isValid() && collection.resourceId() == context()->resource().id()) {
+    if (context().resource().isValid() && collection.resourceId() == context().resource().id()) {
         return true;
     }
     if (sessionId() == collection.resource().name().toUtf8()) {
@@ -482,12 +476,12 @@ void Connection::reportTime() const
 
 void Connection::sendResponse(qint64 tag, const Protocol::CommandPtr &response)
 {
-    if (Tracer::self()->currentTracer() != QLatin1String("null")) {
-        Tracer::self()->connectionOutput(m_identifier, tag, response);
+    if (m_akonadi.tracer().currentTracer() != QLatin1String("null")) {
+        m_akonadi.tracer().connectionOutput(m_identifier, tag, response);
     }
-    Protocol::DataStream stream(m_socket);
+    Protocol::DataStream stream(m_socket.get());
     stream << tag;
-    Protocol::serialize(m_socket, response);
+    Protocol::serialize(m_socket.get(), response);
     if (!m_socket->waitForBytesWritten()) {
         if (m_socket->state() == QLocalSocket::ConnectedState) {
             throw ProtocolException("Server write timeout");
@@ -502,13 +496,13 @@ void Connection::sendResponse(qint64 tag, const Protocol::CommandPtr &response)
 Protocol::CommandPtr Connection::readCommand()
 {
     while (m_socket->bytesAvailable() < (int) sizeof(qint64)) {
-        Protocol::DataStream::waitForData(m_socket, 10000); // 10 seconds, just in case client is busy
+        Protocol::DataStream::waitForData(m_socket.get(), 10000); // 10 seconds, just in case client is busy
     }
 
-    Protocol::DataStream stream(m_socket);
+    Protocol::DataStream stream(m_socket.get());
     qint64 tag;
     stream >> tag;
 
     // TODO: compare tag with m_currentHandler->tag() ?
-    return Protocol::deserialize(m_socket);
+    return Protocol::deserialize(m_socket.get());
 }
